@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from dataclasses import dataclass, field
+from html import escape
 from html.parser import HTMLParser
 from itertools import chain
 from typing import (
@@ -50,15 +51,12 @@ class Node:
         return hash((self.tag, *((key, val) for key, val in self.attrs.items())))
 
     def __iter__(self) -> Iterator[Union[Node, TextNode]]:
-        def gen() -> Iterator[Union[Node, TextNode]]:
-            yield self
-            for child in self.children:
-                if isinstance(child, Node):
-                    yield from iter(child)
-                else:
-                    yield child
-
-        return gen()
+        yield self
+        for child in self.children:
+            if isinstance(child, Node):
+                yield from child
+            else:
+                yield child
 
     def __str__(self) -> str:
         return f"<{self.tag} />"
@@ -122,7 +120,12 @@ def unparse(node: Node) -> str:
     middle = "".join(
         unparse(child)
         if isinstance(child, Node)
-        else (f'<span diff="{True}">{child.text}</span>' if child.diff else child.text)
+        else (
+            f'<span diff="{True}">{escape(child.text)}</span>'
+            if child.diff
+            else escape(child.text)
+        )
         for child in node.children
     )
     return f"{opening}{middle}{closing}"
+
